Index: sasmodels/models/_onion.py
===================================================================
--- sasmodels/models/_onion.py	(revision fdb148728a4d4bdcb4cd711d87631f3ee41993fd)
+++ sasmodels/models/_onion.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -146,5 +146,5 @@
             \frac{j_1(qr_\text{in})}{qr_\text{in}}
 
-.. figure:: img/onion_annotated_profile.gif
+.. figure:: img/onion_geometry.gif
 
     Example of an onion model profile.
@@ -159,12 +159,4 @@
 NB: The outer most radius is used as the effective radius for $S(q)$
 when $P(q) S(q)$ is applied.
-
-.. figure:: img/onion_1d.jpg
-
-    1D plot using the default values (w/400 point)
-
-.. figure:: img/onion_profile.jpg
-
-    SLD profile from the default values.
 
 References
@@ -321,10 +313,7 @@
 
 
-def profile(core_sld, core_radius, solvent_sld, n, in_sld, out_sld, thickness, A):
+def shape(core_sld, core_radius, solvent_sld, n, in_sld, out_sld, thickness, A):
     """
-    Get SLD profile
-
-    Returns *(r, rho(r))* where *r* is the radius (Ang) and *rho(r)* is the
-    SLD (1/Ang^2).
+    SLD profile
     """
 
Index: sasmodels/models/adsorbed_layer.py
===================================================================
--- sasmodels/models/adsorbed_layer.py	(revision cf95788fa5dfeefb731156927adc3d9ac287a55c)
+++ sasmodels/models/adsorbed_layer.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -20,8 +20,4 @@
 
 Note that all parameters except the |sigma| are correlated so fitting more than one of these parameters will generally fail. Also note that unlike other shape models, no volume normalization is applied to this model (the calculation is exact).
-
-.. figure:: img/adsorbed_layer_1d.jpg
-
-    1D plot using the default values.
 
 References
Index: sasmodels/models/barbell.py
===================================================================
--- sasmodels/models/barbell.py	(revision 50e1e40cf14d4ded28bf96e61a3cfaf35003b899)
+++ sasmodels/models/barbell.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -68,21 +68,11 @@
     up to you to restrict this during analysis.
 
-.. figure:: img/barbell_1d.jpg
+The 2D scattering intensity is calculated similar to the 2D cylinder model.
 
-    1D plot using the default values (w/256 data point).
-
-For 2D data, the scattering intensity is calculated similar to the 2D
-cylinder model.
-
-.. figure:: img/barbell_2d.jpg
-
-    2D plot (w/(256X265) data points) for $\theta = 45^\circ$ and
-    $\phi = 0^\circ$ with default values for the remaining parameters.
-
-.. figure:: img/orientation.jpg
+.. figure:: img/cylinder_angle_definition.jpg
 
     Definition of the angles for oriented 2D barbells.
 
-.. figure:: img/orientation2.jpg
+.. figure:: img/cylinder_angle_projection.jpg
 
     Examples of the angles for oriented pp against the detector plane.
Index: sasmodels/models/bcc.py
===================================================================
--- sasmodels/models/bcc.py	(revision ad90df9f3ed42019113506f1366fe4b851b5f389)
+++ sasmodels/models/bcc.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -45,5 +45,5 @@
 
 
-.. figure:: img/bcc_lattice.jpg
+.. figure:: img/bcc_geometry.jpg
 
     Body-centered cubic lattice.
@@ -77,8 +77,4 @@
 *qmin* = 0.001 |Ang^-1|, *qmax* = 0.1 |Ang^-1| and the above default values.
 
-.. figure:: img/bcc_1d.jpg
-
-    1D plot in the linear scale using the default values (w/200 data point).
-
 The 2D (Anisotropic model) is based on the reference below where $I(q)$ is
 approximated for 1d scattering. Thus the scattering pattern for 2D may not
@@ -86,11 +82,7 @@
 model computation.
 
-.. figure:: img/crystal_orientation.png
+.. figure:: img/bcc_angle_definition.png
 
     Orientation of the crystal with respect to the scattering plane.
-
-.. figure:: img/bcc_2d.jpg
-
-    2D plot using the default values (w/200X200 pixels).*
 
 References
Index: sasmodels/models/be_polyelectrolyte.py
===================================================================
--- sasmodels/models/be_polyelectrolyte.py	(revision 0e86967265f7d2cf12cf1cd8abb371e7cc8e8f46)
+++ sasmodels/models/be_polyelectrolyte.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -30,8 +30,4 @@
     q = \sqrt{q_x^2 + q_y^2}
 
-
-.. figure:: img/be_polyelectrolyte_1d.jpg
-
-    1D plot using the default values (w/500 data point).
 
 NB: $1 barn = 10^{-24} cm^2$
Index: sasmodels/models/broad_peak.py
===================================================================
--- sasmodels/models/broad_peak.py	(revision dcdf29d606cfaa2f3bb9d578ac394c6f167fa360)
+++ sasmodels/models/broad_peak.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -28,8 +28,4 @@
     q = \sqrt{q_x^2 + q_y^2}
 
-
-.. figure:: img/broad_peak_1d.jpg
-
-    1D plot using the default values (w/200 data point).
 
 References
Index: sasmodels/models/capped_cylinder.py
===================================================================
--- sasmodels/models/capped_cylinder.py	(revision 50e1e40cf14d4ded28bf96e61a3cfaf35003b899)
+++ sasmodels/models/capped_cylinder.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -69,31 +69,13 @@
     It is up to you to restrict this during analysis.
 
-:num:`Figure #capped-cylinder-1d` shows the output produced by
-a running the 1D capped cylinder model, using *qmin* = 0.001 |Ang^-1|,
-*qmax* = 0.7 |Ang^-1| and  the default values of the parameters.
+The 2D scattering intensity is calculated similar to the 2D cylinder model.
 
-.. _capped-cylinder-1d:
-
-.. figure:: img/capped_cylinder_1d.jpg
-
-    1D plot using the default values (w/256 data point).
-
-The 2D scattering intensity is calculated similar to the 2D cylinder model.
-:num:`Figure #capped-cylinder-2d` shows the output for $\theta=45^\circ$
-and $\phi=0^\circ$ with default values for the other parameters.
-
-.. _capped-cylinder-2d:
-
-.. figure:: img/capped_cylinder_2d.jpg
-
-    2D plot (w/(256X265) data points).
-
-.. figure:: img/orientation.jpg
+.. figure:: img/cylinder_angle_definition.jpg
 
     Definition of the angles for oriented 2D cylinders.
 
-.. figure:: img/orientation2.jpg
+.. figure:: img/cylinder_angle_projection.jpg
 
-    Examples of the angles for oriented pp against the detector plane.
+    Examples of the angles for oriented 2D cylinders against the detector plane.
 
 References
Index: sasmodels/models/core_shell_bicelle.py
===================================================================
--- sasmodels/models/core_shell_bicelle.py	(revision e7678b2f993854334aca4c45e1c7022b2fdbb509)
+++ sasmodels/models/core_shell_bicelle.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -4,6 +4,6 @@
 ----------
 This model provides the form factor for a circular cylinder with a core-shell
-scattering length density profile.
-The form factor is normalized by the particle volume.
+scattering length density profile. The form factor is normalized by the
+particle volume.
 
 .. _core-shell-bicelle-geometry:
@@ -21,13 +21,9 @@
 use the c-library from NIST.
 
-.. figure:: img/core_shell_bicelle_1d.jpg
+.. figure:: img/cylinder_angle_definition.jpg
 
-    1D plot using the default values (w/200 data point).
+    Definition of the angles for the oriented core shell bicelle tmodel.
 
-.. figure:: img/core_shell_bicelle_fig1.jpg
-
-    Definition of the angles for the oriented CoreShellBicelleModel.
-
-.. figure:: img/core_shell_bicelle_fig2.jpg
+.. figure:: img/cylinder_angle_projection.jpg
 
     Examples of the angles for oriented pp against the detector plane.
Index: sasmodels/models/core_shell_cylinder.py
===================================================================
--- sasmodels/models/core_shell_cylinder.py	(revision f0aa7f88c13775739f654942a5ec343bf210d1f5)
+++ sasmodels/models/core_shell_cylinder.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -67,35 +67,10 @@
 Validation of our code was done by comparing the output of the 1D model to
 the output of the software provided by the NIST (Kline, 2006).
-:num:`Figure #core-shell-cylinder-1d` shows a comparison
-of the 1D output of our model and the output of the NIST software.
-
-.. _core-shell-cylinder-1d:
-
-.. figure:: img/core_shell_cylinder_1d.jpg
-
-    Comparison of the SasView scattering intensity for a core-shell cylinder
-    with the output of the NIST SANS analysis software. The parameters were
-    set to: *scale* = 1.0 |Ang|, *radius* = 20 |Ang|, *thickness* = 10 |Ang|,
-    *length* =400 |Ang|, *core_sld* =1e-6 |Ang^-2|, *shell_sld* = 4e-6 |Ang^-2|,
-    *solvent_sld* = 1e-6 |Ang^-2|, and *background* = 0.01 |cm^-1|.
 
 Averaging over a distribution of orientation is done by evaluating the
 equation above. Since we have no other software to compare the
-implementation of the intensity for fully oriented cylinders, we can
-compare the result of averaging our 2D output using a uniform
+implementation of the intensity for fully oriented cylinders, we
+compared the result of averaging our 2D output using a uniform
 distribution $p(\theta,\phi) = 1.0$.
-:num:`Figure #core-shell-cylinder-2d` shows the result
-of such a cross-check.
-
-.. _core-shell-cylinder-2d:
-
-.. figure:: img/core_shell_cylinder_2d.jpg
-
-    Comparison of the intensity for uniformly distributed core-shell
-    cylinders calculated from our 2D model and the intensity from the
-    NIST SANS analysis software. The parameters used were: *scale* = 1.0,
-    *radius* = 20 |Ang|, *thickness* = 10 |Ang|, *length* = 400 |Ang|,
-    *core_sld* = 1e-6 |Ang^-2|, *shell_sld* = 4e-6 |Ang^-2|,
-    *solvent_sld* = 1e-6 |Ang^-2|, and *background* = 0.0 |cm^-1|.
 
 2013/11/26 - Description reviewed by Heenan, R.
Index: sasmodels/models/core_shell_ellipsoid.py
===================================================================
--- sasmodels/models/core_shell_ellipsoid.py	(revision 177c1a138481a9833b4929af687e86583b5c16d5)
+++ sasmodels/models/core_shell_ellipsoid.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -10,5 +10,5 @@
 applied over all orientations for 1D.
 
-.. figure:: img/core_shell_ellipsoid_fig1.gif
+.. figure:: img/core_shell_ellipsoid_geometry.gif
 
     The returned value is in units of $cm^{-1}$, on absolute scale.
@@ -36,5 +36,6 @@
 To provide easy access to the orientation of the core-shell ellipsoid,
 we define the axis of the solid ellipsoid using two angles $\theta$ and $\phi$.
-These angles are defined on Figure 2 of the CylinderModel.
+These angles are defined as for
+:ref:`cylinder orientation <cylinder-angle-definition>`.
 The contrast is defined as SLD(core) - SLD(shell) and SLD(shell) - SLD(solvent).
 
@@ -48,9 +49,5 @@
     and used as the effective radius for *S(Q)* when $P(Q) * S(Q)$ is applied.
 
-.. figure:: img/core_shell_ellipsoid_1d.jpg
-
-    1D plot using the default values (w/200 data point).
-
-.. figure:: img/core_shell_ellipsoid_fig2.jpg
+.. figure:: img/core_shell_ellipsoid_angle_projection.jpg
 
     The angles for oriented core_shell_ellipsoid.
Index: sasmodels/models/core_shell_ellipsoid_xt.py
===================================================================
--- sasmodels/models/core_shell_ellipsoid_xt.py	(revision 3882eeb5b3de1f8eff75651cb6dcd8f9dba766d6)
+++ sasmodels/models/core_shell_ellipsoid_xt.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -10,6 +10,5 @@
 ----------
 
-.. figure:: img/core_shell_ellipsoid_fig1.gif
-
+.. figure:: img/core_shell_ellipsoid_geometry.gif
 
 The geometric parameters of this model are
Index: sasmodels/models/core_shell_parallelepiped.py
===================================================================
--- sasmodels/models/core_shell_parallelepiped.py	(revision 44bd2be361a937362169e016a821f398577e4661)
+++ sasmodels/models/core_shell_parallelepiped.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -22,5 +22,5 @@
 *A* < *B* < *C*.
 
-.. image:: img/core_shell_parallelepiped.jpg
+.. image:: img/core_shell_parallelepiped_geometry.jpg
 
 There are rectangular "slabs" of thickness $t_A$ that add to the *A* dimension
@@ -72,14 +72,14 @@
 To provide easy access to the orientation of the parallelepiped, we define the
 axis of the cylinder using three angles |theta|, |phi| and |bigpsi|.
-These angles are defined on Figure 2 of the :ref:`cylinder` model.
+(see :ref:`cylinder orientation <cylinder-angle-definition>`).
 The angle |bigpsi| is the rotational angle around the *long_c* axis against the
 *q* plane. For example, |bigpsi| = 0 when the *short_b* axis is parallel to the
 *x*-axis of the detector.
 
-.. figure:: img/parallelepiped_angles_definition.jpg
+.. figure:: img/parallelepiped_angle_definition.jpg
 
     Definition of the angles for oriented core-shell parallelepipeds.
 
-.. figure:: img/parallelepiped_angles_examples.jpg
+.. figure:: img/parallelepiped_angle_projection.jpg
 
     Examples of the angles for oriented core-shell parallelepipeds against the
Index: sasmodels/models/cylinder.py
===================================================================
--- sasmodels/models/cylinder.py	(revision 50e1e40cf14d4ded28bf96e61a3cfaf35003b899)
+++ sasmodels/models/cylinder.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -31,13 +31,13 @@
 To provide easy access to the orientation of the cylinder, we define the
 axis of the cylinder using two angles $\theta$ and $\phi$. Those angles
-are defined in :num:`figure #cylinder-orientation`.
+are defined in :num:`figure #cylinder-angle-definition`.
 
-.. _cylinder-orientation:
+.. _cylinder-angle-definition:
 
-.. figure:: img/orientation.jpg
+.. figure:: img/cylinder_angle_definition.jpg
 
     Definition of the angles for oriented cylinders.
 
-.. figure:: img/orientation2.jpg
+.. figure:: img/cylinder_angle_projection.jpg
 
     Examples of the angles for oriented cylinders against the detector plane.
Index: sasmodels/models/ellipsoid.py
===================================================================
--- sasmodels/models/ellipsoid.py	(revision 431caaea11d3494f5958adb99c85a4cd92f1290c)
+++ sasmodels/models/ellipsoid.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -47,11 +47,4 @@
 $S(q)$ when $P(q) \cdot S(q)$ is applied.
 
-.. _ellipsoid-1d:
-
-.. figure:: img/ellipsoid_1d.jpg
-
-    The output of the 1D scattering intensity function for randomly oriented
-    ellipsoids given by the equation above.
-
 
 The $\theta$ and $\phi$ parameters are not used for the 1D output.
@@ -59,5 +52,5 @@
 .. _ellipsoid-geometry:
 
-.. figure:: img/ellipsoid_geometry.jpg
+.. figure:: img/ellipsoid_angle_projection.jpg
 
     The angles for oriented ellipsoid.
Index: sasmodels/models/elliptical_cylinder.py
===================================================================
--- sasmodels/models/elliptical_cylinder.py	(revision fa8011eb0e6b527e15b594945876ee39b6a46dbd)
+++ sasmodels/models/elliptical_cylinder.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -43,15 +43,15 @@
 
 To provide easy access to the orientation of the elliptical cylinder, we define the axis of the cylinder using two
-angles |theta|, |phi| and |bigpsi|. As for the case of the cylinder, the angles |theta| and |phi| are defined on
-Figure 2 of CylinderModel. The angle |bigpsi| is the rotational angle around its own long_c axis against the *q* plane.
+angles |theta|, |phi| and |bigpsi| (see :ref:`cylinder orientation <cylinder-angle-definition>`).
+The angle |bigpsi| is the rotational angle around its own long_c axis against the *q* plane.
 For example, |bigpsi| = 0 when the *r_minor* axis is parallel to the *x*\ -axis of the detector.
 
 All angle parameters are valid and given only for 2D calculation; ie, an oriented system.
 
-.. figure:: img/elliptical_cylinder_geometry_2d.jpg
+.. figure:: img/elliptical_cylinder_angle_definition.jpg
 
     Definition of angles for 2D
 
-.. figure:: img/core_shell_bicelle_fig2.jpg
+.. figure:: img/cylinder_angle_projection.jpg
 
     Examples of the angles for oriented elliptical cylinders against the detector plane.
@@ -60,8 +60,4 @@
 and length values, and used as the effective radius for *S(Q)* when *P(Q)* \* *S(Q)* is applied.
 
-
-.. figure:: img/elliptical_cylinder_comparison_1d.jpg
-
-    1D plot using the default values (w/1000 data point).
 
 Validation
Index: sasmodels/models/fcc.py
===================================================================
--- sasmodels/models/fcc.py	(revision ad90df9f3ed42019113506f1366fe4b851b5f389)
+++ sasmodels/models/fcc.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -43,5 +43,5 @@
 where $g$ is a fractional distortion based on the nearest neighbor distance.
 
-.. figure:: img/fcc_lattice.jpg
+.. figure:: img/fcc_geometry.jpg
 
     Face-centered cubic lattice.
@@ -71,11 +71,4 @@
 integral. Very, very slow. Go get lunch!
 
-This example dataset is produced using 200 data points, *qmin* = 0.01 |Ang^-1|,
-*qmax* = 0.1 |Ang^-1| and the above default values.
-
-.. figure:: img/fcc_1d.jpg
-
-    1D plot in the linear scale using the default values (w/200 data point).
-
 The 2D (Anisotropic model) is based on the reference below where $I(q)$ is
 approximated for 1d scattering. Thus the scattering pattern for 2D may not
@@ -83,11 +76,7 @@
 2D model computation.
 
-.. figure:: img/crystal_orientation.png
+.. figure:: img/bcc_angle_definition.png
 
     Orientation of the crystal with respect to the scattering plane.
-
-.. figure:: img/fcc_2d.jpg
-
-    2D plot using the default values (w/200X200 pixels).
 
 References
Index: sasmodels/models/hollow_cylinder.py
===================================================================
--- sasmodels/models/hollow_cylinder.py	(revision e0fd91396c863eb30f45111903316f0bde64c127)
+++ sasmodels/models/hollow_cylinder.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -34,8 +34,4 @@
 Bessel function.
 
-To provide easy access to the orientation of the core-shell cylinder, we define
-the axis of the cylinder using two angles $\theta$ and $\phi$. As for the case
-of the cylinder, those angles are defined in Figure 2 of the CylinderModel.
-
 **NB**: The 2nd virial coefficient of the cylinder is calculated
 based on the radius and 2 length values, and used as the effective radius
@@ -45,15 +41,7 @@
 and the *radius* is $R_\text{shell}$ while *core_radius* is $R_\text{core}$.
 
-.. figure:: img/hollow_cylinder_1d.jpg
-
-    1D plot using the default values (w/1000 data point).
-
-.. figure:: img/orientation.jpg
-
-    Definition of the angles for the oriented hollow_cylinder model.
-
-.. figure:: img/orientation2.jpg
-
-    Examples of the angles for oriented pp against the detector plane.
+To provide easy access to the orientation of the core-shell cylinder, we define
+the axis of the cylinder using two angles $\theta$ and $\phi$
+(see :ref:`cylinder model <cylinder-angle-definition>`).
 
 References
Index: sasmodels/models/linear_pearls.py
===================================================================
--- sasmodels/models/linear_pearls.py	(revision 32c743d8fe636333bd6fa7aa99f46c623b72890c)
+++ sasmodels/models/linear_pearls.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -5,5 +5,5 @@
 The thickness of each string is assumed to be negligible.
 
-.. figure:: img/linear_pearls_fig1.jpg
+.. figure:: img/linear_pearls_geometry.jpg
 
 
@@ -25,8 +25,4 @@
 The 2D scattering intensity is the same as P(q) above,
 regardless of the orientation of the q vector.
-
-.. figure:: img/linear_pearls_1d.jpg
-
-    1D plot using the default values (w/500 data point).
 
 References
Index: sasmodels/models/multi_shell.py
===================================================================
--- sasmodels/models/multi_shell.py	(revision d51ea74056d9370690a3247b3f61a63cf942f189)
+++ sasmodels/models/multi_shell.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -19,5 +19,5 @@
 parameters fixed as possible.
 
-.. figure:: img/multi_shell_fig1.jpg
+.. figure:: img/multi_shell_geometry.jpg
 
 The 2D scattering intensity is the same as 1D, regardless of the orientation
@@ -33,8 +33,4 @@
     is used as the effective radius for *S(Q)* when $P(Q) * S(Q)$ is applied.
 
-
-.. figure:: img/multi_shell_1d.jpg
-
-    1D plot using the default values (with 200 data point).
 
 Our model uses the form factor calculations implemented in a c-library provided
Index: sasmodels/models/parallelepiped.py
===================================================================
--- sasmodels/models/parallelepiped.py	(revision deb7ee06caa9916d8c0504bdc15ffbc16df623f6)
+++ sasmodels/models/parallelepiped.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -99,9 +99,9 @@
 .. _parallelepiped-orientation:
 
-.. figure:: img/parallelepiped_angles_definition.jpg
+.. figure:: img/parallelepiped_angle_definition.jpg
 
     Definition of the angles for oriented parallelepipeds.
 
-.. figure:: img/parallelepiped_angles_examples.jpg
+.. figure:: img/parallelepiped_angle_projection.jpg
 
     Examples of the angles for oriented parallelepipeds against the detector plane.
@@ -156,5 +156,4 @@
 This model is based on form factor calculations implemented in a c-library
 provided by the NIST Center for Neutron Research (Kline, 2006).
-
 """
 
Index: sasmodels/models/pearl_necklace.py
===================================================================
--- sasmodels/models/pearl_necklace.py	(revision d18582e2d66b12afb03e1c3a7c0af6e4449c6bfe)
+++ sasmodels/models/pearl_necklace.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -6,5 +6,5 @@
 (= *A* - 2\ *R*)). *A* is the center-to-center pearl separation distance.
 
-.. figure:: img/pearl_fig.jpg
+.. figure:: img/pearl_necklace_geometry.jpg
 
     Pearl Necklace schematic
@@ -48,9 +48,6 @@
 NB: *number_of_pearls* must be an integer.
 
-.. figure:: img/pearl_plot.jpg
-
-    1D plot using the default values (w/1000 data point).
-
-REFERENCE
+References
+----------
 
 R Schweins and K Huber, *Particle Scattering Factor of Pearl Necklace Chains*,
Index: sasmodels/models/sc_crystal.py
===================================================================
--- sasmodels/models/sc_crystal.py	(revision ad90df9f3ed42019113506f1366fe4b851b5f389)
+++ sasmodels/models/sc_crystal.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -41,5 +41,5 @@
 The simple cubic lattice is
 
-.. figure:: img/sc_crystal_fig1.jpg
+.. figure:: img/sc_crystal_geometry.jpg
 
 For a crystal, diffraction peaks appear at reduced q-values given by
@@ -77,11 +77,4 @@
     Go get lunch!
 
-This example dataset is produced using 200 data points,
-$q_{min} = 0.01A^{-1}, q_{max} = 0.1A^{-1}$ and the above default values.
-
-.. figure:: img/sc_crystal_1d.jpg
-
-    1D plot in the linear scale using the default values (w/200 data point).
-
 The 2D (Anisotropic model) is based on the reference below where *I(q)* is
 approximated for 1d scattering. Thus the scattering pattern for 2D may not
@@ -89,8 +82,5 @@
 model computation.
 
-.. figure:: img/sc_crystal_fig2.jpg
-.. figure:: img/sc_crystal_fig3.jpg
-
-    2D plot using the default values (w/200X200 pixels).
+.. figure:: img/sc_crystal_angle_definition.jpg
 
 Reference
Index: sasmodels/models/stacked_disks.py
===================================================================
--- sasmodels/models/stacked_disks.py	(revision d507c3a946bb1b2103ca169efe83263b3955b43d)
+++ sasmodels/models/stacked_disks.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -21,5 +21,5 @@
 ----------
 
-.. figure:: img/stacked_disks_fig1.gif
+.. figure:: img/stacked_disks_geometry.gif
 
 The scattered intensity $I(q)$ is calculated as
@@ -68,8 +68,4 @@
 and $\sigma_D$ = the Gaussian standard deviation of the d-spacing (sigma_d).
 
-To provide easy access to the orientation of the stacked disks, we define
-the axis of the cylinder using two angles $\theta$ and $\varphi$.
-These angles are defined on Figure 2 of cylinder_model.
-
 .. note::
     The 2nd virial coefficient of the cylinder is calculated based on the
@@ -78,14 +74,13 @@
     is applied.
 
-.. figure:: img/stacked_disks_1d.jpg
-
-    1D plot using the default values (w/1000 data point).
-
-.. figure:: img/stacked_disks_fig2.jpg
+To provide easy access to the orientation of the stacked disks, we define
+the axis of the cylinder using two angles $\theta$ and $\varphi$.
+
+.. figure:: img/stacked_disks_angle_definition.jpg
 
     Examples of the angles for oriented stacked disks against
     the detector plane.
 
-.. figure:: img/stacked_disks_fig3.jpg
+.. figure:: img/stacked_disks_angle_projection.jpg
 
     Examples of the angles for oriented pp against the detector plane.
Index: sasmodels/models/triaxial_ellipsoid.py
===================================================================
--- sasmodels/models/triaxial_ellipsoid.py	(revision 469e763f1e5fc119d32baa75e7d38058e275d079)
+++ sasmodels/models/triaxial_ellipsoid.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -43,5 +43,5 @@
 .. _triaxial-ellipsoid-angles:
 
-.. figure:: img/triaxial_ellipsoid_angles.jpg
+.. figure:: img/triaxial_ellipsoid_angle_projection.jpg
 
     The angles for oriented ellipsoid.
@@ -57,8 +57,4 @@
 radius $R_e = \sqrt{R_a R_b}$, and used as the effective radius for
 $S(q)$ when $P(q) \cdot S(q)$ is applied.
-
-.. figure:: img/triaxial_ellipsoid_1d.jpg
-
-    1D plot using the default values (w/1000 data point).
 
 Validation

Index: sasmodels/generate.py
===================================================================
--- sasmodels/generate.py	(revision 91c5fdc1e57978ebef854d27add589c392a93f3a)
+++ sasmodels/generate.py	(revision 2f0c07deb2cb7a8c0c93476fbf1e0ffbe6c278cb)
@@ -672,5 +672,5 @@
     * *tests* is a set of tests that must pass
     * *source* is the list of library files to include in the C model build
     * *Iq*, *Iqxy*, *form_volume*, *ER*, and *VR* are python functions
       implementing the kernel for the module, or None if they are not
       defined in python
@@ -682,4 +682,5 @@
       *model_info* blocks for the composition objects.  This allows us to
       build complete product and mixture models from just the info.
+
     """
     # TODO: maybe turn model_info into a class ModelDefinition
@@ -710,7 +711,7 @@
         )
     process_parameters(model_info)
-    # Fill in available functions
-    model_info.update((k, getattr(kernel_module, k, None))
-                      for k in ('ER', 'VR', 'form_volume', 'Iq', 'Iqxy'))
+    # Check for optional functions
+    functions = "ER VR form_volume Iq Iqxy shape sesans".split()
+    model_info.update((k, getattr(kernel_module, k, None)) for k in functions)
     return model_info
 
@@ -672,5 +672,5 @@
     * *tests* is a set of tests that must pass
     * *source* is the list of library files to include in the C model build
-    * *Iq*, *Iqxy*, *form_volume*, *ER*, and *VR* are python functions
+    * *Iq*, *Iqxy*, *form_volume*, *ER*, *VR* and *sesans* are python functions
       implementing the kernel for the module, or None if they are not
       defined in python